[devel] Imported from libpng-1.4.0beta68.tar
diff --git a/ANNOUNCE b/ANNOUNCE
index 5c982db..fe46ff1 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
 
-Libpng 1.4.0beta68 - July 18, 2009
+Libpng 1.4.0beta68 - July 19, 2009
 
 This is not intended to be a public release.  It will be replaced
 within a few weeks by a public version or by another test version.
@@ -499,7 +499,7 @@
   Added high-level API transform PNG_TRANSFORM_GRAY_TO_RGB.
   Added an "xcode" project to the projects directory (Alam Arias).
 
-version 1.4.0beta68 [July 18, 2009]
+version 1.4.0beta68 [July 19, 2009]
   Avoid some tests in filter selection in pngwutil.c
 
 version 1.4.0betaN [future]
diff --git a/CHANGES b/CHANGES
index d202d43..d8ae10c 100644
--- a/CHANGES
+++ b/CHANGES
@@ -1,5 +1,5 @@
 #if 0
-changes(){ /*
+libpng_changes(){ /*
 CHANGES - changes for libpng
 
 version 0.2
@@ -540,7 +540,8 @@
   Eliminated pngtypes.h; use macros instead to declare PNG_CHNK arrays.
   Renamed "PNG_GLOBAL_ARRAYS" to "PNG_USE_GLOBAL_ARRAYS" and made available
     to applications a macro "PNG_USE_LOCAL_ARRAYS".
-  #ifdef out all the new declarations when PNG_USE_GLOBAL_ARRAYS is defined.
+  comment out (with #ifdef) all the new declarations when
+    PNG_USE_GLOBAL_ARRAYS is defined.
   Added PNG_EXPORT_VAR macro to accommodate making DLL's.
 version 1.0.5e [November 30, 1999]
   Added iCCP, iTXt, and sPLT support; added "lang" member to the png_text
@@ -1301,7 +1302,7 @@
   Added PNG_NO_SEQUENTIAL_READ_SUPPORTED macro to conditionally remove
     sequential read support.
   Added some "#if PNG_WRITE_SUPPORTED" blocks.
-  #ifdef'ed out some redundancy in png_malloc_default().
+  Added #ifdef to remove some redundancy in png_malloc_default().
   Use png_malloc instead of png_zalloc to allocate the pallete.
 version 1.0.16rc1 and 1.2.6rc1 [August 4, 2004]
   Fixed buffer overflow vulnerability in png_handle_tRNS()
@@ -1371,7 +1372,8 @@
   Fixed bug, introduced in libpng-1.2.7, that overruns a buffer during
     strip alpha operation in png_do_strip_filler().
   Added PNG_1_2_X definition in pngconf.h
-  #ifdef out png_info_init in png.c and png_read_init in pngread.c (as of 1.3.0)
+  Use #ifdef to comment out png_info_init in png.c and png_read_init in
+    pngread.c (as of 1.3.0)
 version 1.2.8beta2 [November 2, 2004]
   Reduce color_type to a nonalpha type after strip alpha operation in
     png_do_strip_filler().
@@ -1757,8 +1759,8 @@
   Added a special "_MSC_VER" case that defines png_snprintf to _snprintf
 
 version 1.2.19beta7 [May 22, 2007]
-  Squelched png_squelch_warnings() in pnggccrd.c and added an
-    #ifdef PNG_MMX_CODE_SUPPORTED block around the declarations that caused
+  Squelched png_squelch_warnings() in pnggccrd.c and added
+    an #ifdef PNG_MMX_CODE_SUPPORTED block around the declarations that caused
     the warnings that png_squelch_warnings was squelching.
 
 version 1.2.19beta8 [May 22, 2007]
@@ -2176,7 +2178,7 @@
   Added high-level API transform PNG_TRANSFORM_GRAY_TO_RGB.
   Added an "xcode" project to the projects directory (Alam Arias).
 
-version 1.4.0beta68 [July 18, 2009]
+version 1.4.0beta68 [July 19, 2009]
   Avoid some tests in filter selection in pngwutil.c
 
 version 1.4.0betaN [future]
diff --git a/INSTALL b/INSTALL
index d35bb8a..f402068 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,5 +1,5 @@
 
-Installing libpng version 1.4.0beta68 - July 7, 2009
+Installing libpng version 1.4.0beta68 - July 19, 2009
 
 On Unix/Linux and similar systems, you can simply type
 
diff --git a/LICENSE b/LICENSE
index 30db496..e151f29 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.4.0beta68, July 7, 2009, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.0beta68, July 19, 2009, are
 Copyright (c) 2004, 2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-July 7, 2009
+July 19, 2009
diff --git a/Makefile.am b/Makefile.am
index 31f6972..1098e7d 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -16,7 +16,7 @@
 # test programs - run on make check, make distcheck
 check_PROGRAMS= pngtest
 pngtest_SOURCES = pngtest.c
-pngtest_LDADD = libpng14.la
+pngtest_LDADD = libpng%NN%.la
 TESTS = test-pngtest.sh
 TESTS_ENVIRONMENT= srcdir=$(srcdir) 
 
@@ -24,39 +24,39 @@
 dist_man_MANS= libpng.3 libpngpf.3 png.5
 
 # generate the -config scripts if required
-binconfigs= libpng14-config 
-EXTRA_SCRIPTS= libpng-config libpng14-config
+binconfigs= libpng%NN%-config 
+EXTRA_SCRIPTS= libpng-config libpng%NN%-config
 bin_SCRIPTS= @binconfigs@
 
 # rules to build libpng, only build the old library on request
-lib_LTLIBRARIES=libpng14.la @compatlib@
+lib_LTLIBRARIES=libpng%NN%.la @compatlib@
 EXTRA_LTLIBRARIES= libpng.la
-libpng14_la_SOURCES = png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
+libpng%NN%_la_SOURCES = png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c \
 	png.h pngconf.h
-libpng_la_SOURCES = $(libpng14_la_SOURCES)
+libpng_la_SOURCES = $(libpng%NN%_la_SOURCES)
 
 libpng_la_CPPFLAGS = @LIBPNG_DEFINES@
-libpng14_la_CPPFLAGS = @LIBPNG_DEFINES@
+libpng%NN%_la_CPPFLAGS = @LIBPNG_DEFINES@
 
 # MAJOR UPGRADE: the version-number settings below must be changed.
-libpng14_la_LDFLAGS = -no-undefined -export-dynamic \
-	-version-number 14:@PNGLIB_RELEASE@:14
+libpng%NN%_la_LDFLAGS = -no-undefined -export-dynamic \
+	-version-number %NN%:@PNGLIB_RELEASE@:%NN%
 # -rpath is needed as automake doesn't know the directory
 libpng_la_LDFLAGS = -rpath '$(libdir)' -no-undefined -export-dynamic \
-	-version-number 14:@PNGLIB_RELEASE@:14
+	-version-number 14:@PNGLIB_RELEASE@:%NN%
 
 if HAVE_LD_VERSION_SCRIPT
   # Versioned symbols and restricted exports
-  libpng14_la_LDFLAGS += -Wl,--version-script=libpng.vers
-  libpng14_la_DEPENDENCIES = libpng.vers
+  libpng%NN%_la_LDFLAGS += -Wl,--version-script=libpng.vers
+  libpng%NN%_la_DEPENDENCIES = libpng.vers
 else
   # Only restricted exports when possible
-  libpng14_la_LDFLAGS += -export-symbols libpng.sym
-  libpng14_la_DEPENDENCIES = libpng.sym
+  libpng%NN%_la_LDFLAGS += -export-symbols libpng.sym
+  libpng%NN%_la_DEPENDENCIES = libpng.sym
 endif
-libpng_la_DEPENDENCIES = $(libpng14_la_DEPENDENCIES)
+libpng_la_DEPENDENCIES = $(libpng%NN%_la_DEPENDENCIES)
 
 # Avoid depending upon Character Ranges.
 AN = '_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789'
@@ -68,7 +68,7 @@
 # pkg-config stuff, note that libpng.pc is always required in order
 # to get the correct library
 pkgconfigdir = @pkgconfigdir@
-pkgconfig_DATA = libpng14.pc
+pkgconfig_DATA = libpng%NN%.pc
 
 #extra source distribution files.
 EXTRA_DIST= \
@@ -88,7 +88,7 @@
 	$(TESTS) \
 	example.c libpng-1.4.0beta68.txt pngvcrd.c 
 
-CLEANFILES= pngout.png libpng14.pc libpng14-config libpng.vers \
+CLEANFILES= pngout.png libpng%NN%.pc libpng%NN%-config libpng.vers \
 libpng.sym
 
 MAINTAINERCLEANFILES = Makefile.in aclocal.m4 config.guess config.h.in \
@@ -127,7 +127,7 @@
 	cd $(DESTDIR)$(pkgconfigdir); rm -f libpng.pc
 	cd $(DESTDIR)$(pkgconfigdir); $(LN_S) $(PNGLIB_BASENAME).pc libpng.pc
 
-# do evil things to libpng to cause libpng14 to be used
+# do evil things to libpng to cause libpng%NN% to be used
 install-exec-hook:
 	cd $(DESTDIR)$(bindir); rm -f libpng-config
 	cd $(DESTDIR)$(bindir); $(LN_S) $(PNGLIB_BASENAME)-config libpng-config
diff --git a/README b/README
index eca4811..ee6e36f 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.4.0beta68 - July 7, 2009 (shared library 14.0)
+README for libpng version 1.4.0beta68 - July 19, 2009 (shared library 14.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
diff --git a/contrib/visupng/PngFile.c b/contrib/visupng/PngFile.c
index b5e1259..6154ce2 100644
--- a/contrib/visupng/PngFile.c
+++ b/contrib/visupng/PngFile.c
@@ -5,8 +5,8 @@
 // Copyright 2000, Willem van Schaik.
 //
 // This code is released under the libpng license.
-// For conditions of distribution and use, see the
-// copyright/license/disclaimer notice in png.h
+// For conditions of distribution and use, see the disclaimer
+// and license in png.h
 
 #include <windows.h>
 #include <commdlg.h>
diff --git a/contrib/visupng/PngFile.h b/contrib/visupng/PngFile.h
index b383fc8..f695811 100644
--- a/contrib/visupng/PngFile.h
+++ b/contrib/visupng/PngFile.h
@@ -3,10 +3,10 @@
 //------------------------------------------
 
 // Copyright 2000, Willem van Schaik.
-//
+
 // This code is released under the libpng license.
-// For conditions of distribution and use, see the
-// copyright/license/disclaimer notice in png.h
+// For conditions of distribution and use, see the disclaimer
+// and license in png.h
 
 #include <stdio.h>
 #include <stdlib.h>
diff --git a/contrib/visupng/README.txt b/contrib/visupng/README.txt
index deee654..4047119 100644
--- a/contrib/visupng/README.txt
+++ b/contrib/visupng/README.txt
@@ -4,8 +4,8 @@
 Copyright 2000, Willem van Schaik.
 
 This code is released under the libpng license.
-For conditions of distribution and use, see the
-copyright/license/disclaimer notice in png.h
+For conditions of distribution and use, see the disclaimer
+and license in png.h
 
 As a PNG .dll demo VisualPng is finished. More features would only hinder
 the program's objective. However, further extensions (like support for other 
diff --git a/contrib/visupng/VisualPng.c b/contrib/visupng/VisualPng.c
index 1192384..2018999 100644
--- a/contrib/visupng/VisualPng.c
+++ b/contrib/visupng/VisualPng.c
@@ -3,10 +3,10 @@
 //------------------------------------
 
 // Copyright 2000, Willem van Schaik.
-//
+
 // This code is released under the libpng license.
-// For conditions of distribution and use, see the
-// copyright/license/disclaimer notice in png.h
+// For conditions of distribution and use, see the disclaimer
+// and license in png.h
 
 // switches
 
diff --git a/example.c b/example.c
index e435608..d565bc3 100644
--- a/example.c
+++ b/example.c
@@ -2,7 +2,7 @@
 #if 0 /* in case someone actually tries to compile this */
 
 /* example.c - an example of using libpng
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * This file has been placed in the public domain by the authors.
  * Maintained 1998-2009 Glenn Randers-Pehrson
  * Maintained 1996, 1997 Andreas Dilger)
diff --git a/libpng-1.4.0beta68.txt b/libpng-1.4.0beta68.txt
index af84ed8..b55011c 100644
--- a/libpng-1.4.0beta68.txt
+++ b/libpng-1.4.0beta68.txt
@@ -1,6 +1,6 @@
 libpng.txt - A description on how to use and modify libpng
 
- libpng version 1.4.0beta68 - July 7, 2009
+ libpng version 1.4.0beta68 - July 19, 2009
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.4.0beta68 - July 7, 2009
+ libpng versions 0.97, January 1998, through 1.4.0beta68 - July 19, 2009
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
 
@@ -3162,7 +3162,7 @@
 
 XIII. Y2K Compliance in libpng
 
-July 7, 2009
+July 19, 2009
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
diff --git a/libpng.3 b/libpng.3
index ba17074..7899249 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "July 7, 2009"
+.TH LIBPNG 3 "July 19, 2009"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.4.0beta68
 .SH SYNOPSIS
@@ -809,7 +809,7 @@
 .SH LIBPNG.TXT
 libpng.txt - A description on how to use and modify libpng
 
- libpng version 1.4.0beta68 - July 7, 2009
+ libpng version 1.4.0beta68 - July 19, 2009
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
@@ -820,7 +820,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.4.0beta68 - July 7, 2009
+ libpng versions 0.97, January 1998, through 1.4.0beta68 - July 19, 2009
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2009 Glenn Randers-Pehrson
 
@@ -3971,7 +3971,7 @@
 
 .SH XIII. Y2K Compliance in libpng
 
-July 7, 2009
+July 19, 2009
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
@@ -4201,7 +4201,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.4.0beta68 - July 7, 2009:
+Libpng version 1.4.0beta68 - July 19, 2009:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -4224,7 +4224,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.4.0beta68, July 7, 2009, are
+libpng versions 1.2.6, August 15, 2004, through 1.4.0beta68, July 19, 2009, are
 Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -4323,7 +4323,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-July 7, 2009
+July 19, 2009
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index 7df05c5..fa67a84 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "July 7, 2009"
+.TH LIBPNGPF 3 "July 19, 2009"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.4.0beta68
 (private functions)
diff --git a/png.5 b/png.5
index bb273c2..6a1163a 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "July 7, 2009"
+.TH PNG 5 "July 19, 2009"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/pngconf.h b/pngconf.h
index ad6820d..cc11c9a 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version 1.4.0beta68 - July 7, 2009
+ * libpng version 1.4.0beta68 - July 19, 2009
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngerror.c b/pngerror.c
index 6653e4d..fb1178c 100644
--- a/pngerror.c
+++ b/pngerror.c
@@ -1,7 +1,7 @@
 
 /* pngerror.c - stub functions for i/o and memory allocation
  *
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngget.c b/pngget.c
index 39d0ef8..5000192 100644
--- a/pngget.c
+++ b/pngget.c
@@ -1,7 +1,7 @@
 
 /* pngget.c - retrieval of values from info struct
  *
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngmem.c b/pngmem.c
index 302fc5f..d1da5e6 100644
--- a/pngmem.c
+++ b/pngmem.c
@@ -1,7 +1,7 @@
 
 /* pngmem.c - stub functions for memory allocation
  *
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngpread.c b/pngpread.c
index 2abc7c7..32c0946 100644
--- a/pngpread.c
+++ b/pngpread.c
@@ -1,7 +1,7 @@
 
 /* pngpread.c - read a png file in push mode
  *
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngpriv.h b/pngpriv.h
index 2c09e27..62da255 100644
--- a/pngpriv.h
+++ b/pngpriv.h
@@ -1,7 +1,7 @@
 
 /* pngpriv.h - private declarations for use inside libpng
  *
- * libpng version 1.4.0beta68 - July 7, 2009
+ * libpng version 1.4.0beta68 - July 19, 2009
  * For conditions of distribution and use, see copyright notice in png.h
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngread.c b/pngread.c
index 89742f0..ffb0451 100644
--- a/pngread.c
+++ b/pngread.c
@@ -1,7 +1,7 @@
 
 /* pngread.c - read a PNG file
  *
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngrio.c b/pngrio.c
index a60fc83..58c2d56 100644
--- a/pngrio.c
+++ b/pngrio.c
@@ -1,7 +1,7 @@
 
 /* pngrio.c - functions for data input
  *
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngrtran.c b/pngrtran.c
index 0327d45..be62d64 100644
--- a/pngrtran.c
+++ b/pngrtran.c
@@ -1,7 +1,7 @@
 
 /* pngrtran.c - transforms the data in a row for PNG readers
  *
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngrutil.c b/pngrutil.c
index b4f45f9..064b8d6 100644
--- a/pngrutil.c
+++ b/pngrutil.c
@@ -1,7 +1,7 @@
 
 /* pngrutil.c - utilities to read a PNG file
  *
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngset.c b/pngset.c
index 18c39fa..092b19f 100644
--- a/pngset.c
+++ b/pngset.c
@@ -1,7 +1,7 @@
 
 /* pngset.c - storage of image information into info struct
  *
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngtest.c b/pngtest.c
index 995d2c9..55dcad4 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1,7 +1,7 @@
 
 /* pngtest.c - a simple test program to test libpng
  *
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngtrans.c b/pngtrans.c
index a2b4b61..56235bc 100644
--- a/pngtrans.c
+++ b/pngtrans.c
@@ -1,7 +1,7 @@
 
 /* pngtrans.c - transforms the data in a row (used by both readers and writers)
  *
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngwio.c b/pngwio.c
index 4730da7..2ec7bb7 100644
--- a/pngwio.c
+++ b/pngwio.c
@@ -1,7 +1,7 @@
 
 /* pngwio.c - functions for data output
  *
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngwrite.c b/pngwrite.c
index 3fdd884..e3259a6 100644
--- a/pngwrite.c
+++ b/pngwrite.c
@@ -1,7 +1,7 @@
 
 /* pngwrite.c - general routines to write a PNG file
  *
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngwtran.c b/pngwtran.c
index 26a6493..fa025f8 100644
--- a/pngwtran.c
+++ b/pngwtran.c
@@ -1,7 +1,7 @@
 
 /* pngwtran.c - transforms the data in a row for PNG writers
  *
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/png.c b/png.c
index 20cbab3..5f42ed8 100644
--- a/png.c
+++ b/png.c
@@ -1,7 +1,7 @@
 
 /* png.c - location for general purpose libpng functions
  *
  * Last changed in libpng 1.4.0 [July 7, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -652,13 +652,13 @@
 #else
 #ifdef __STDC__
    return ((png_charp) PNG_STRING_NEWLINE \
-     "libpng version x 1.4.0beta68 - July 7, 2009" PNG_STRING_NEWLINE \
+     "libpng version x 1.4.0beta68 - July 19, 2009" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2009 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE);
 #else
-      return ((png_charp) "libpng version 1.4.0beta68 - July 7, 2009\
+      return ((png_charp) "libpng version 1.4.0beta68 - July 19, 2009\
       Copyright (c) 1998-2009 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
@@ -1,7 +1,7 @@
 /* png.c - location for general purpose libpng functions
  *
- * Last changed in libpng 1.4.0 [July 7, 2009]
+ * Last changed in libpng 1.4.0 [July 19, 2009]
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/png.h b/png.h
index 5a39be8..369f7ab 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.4.0beta68 - July 7, 2009
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *  libpng versions 0.97, January 1998, through 1.4.0beta68 - July 7, 2009: Glenn
  *  See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -161,7 +161,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.4.0beta68, July 7, 2009, are
  * Copyright (c) 2004, 2006-2007 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -337,7 +337,7 @@
 /* Version information for png.h - this should match the version in png.c */
 #define PNG_LIBPNG_VER_STRING "1.4.0beta68"
 #define PNG_HEADER_VERSION_STRING \
-   " libpng version 1.4.0beta68 - July 7, 2009\n"
+   " libpng version 1.4.0beta68 - July 19, 2009\n"
 
 #define PNG_LIBPNG_VER_SONUM   14
 #define PNG_LIBPNG_VER_DLLNUM  14
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.4.0beta68 - July 7, 2009
+ * libpng version 1.4.0beta68 - July 19, 2009
  * Copyright (c) 1998-2009 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *  libpng versions 0.97, January 1998, through 1.4.0beta68 - July 7, 2009: Glenn
+ *  libpng versions 0.97, January 1998, through 1.4.0beta68 - July 19, 2009: Glenn
  *  See also "Contributing Authors", below.
  *
@@ -161,7 +161,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.4.0beta68, July 7, 2009, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.4.0beta68, July 19, 2009, are
  * Copyright (c) 2004, 2006-2007 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5